@@ -14,7 +14,7 @@ tar xf $orig_tar -C $TMPDIR
 srcdir=$TMPDIR/*
 echo $srcdir
 rm -rf $srcdir/sofa* $srcdir/pal* $srcdir/Ers.h \
-       $srcdir/sun???.htx_tar $srcdir/sun???.ps
+       $srcdir/sun???.htx_tar $srcdir/sun???.ps $srcdir/sun???.pdf
 
 dfsg_tar=$tardir/starlink-ast_$ver+dfsg.orig.tar.gz
 tar czf $dfsg_tar -C $TMPDIR .
